@@ -24,23 +24,22 @@
 #include "config.h"
 #endif
 
-/* Gtk/Glib includes */
 #include <glib.h>
-#include <NVCtrl/NVCtrl.h>
+#include "xfce4++/util.h"
+
+#include "types.h"
 
 /**
  * Initialize nvidia sensor
- * @param arr_ptr_chips: Pointer to pointer array to chips
  * @return number of detected chip features
  */
-int initialize_nvidia (GPtrArray *arr_ptr_chips);
+int initialize_nvidia (std::vector<Ptr<t_chip>> &chips);
 
 /**
  * Refresh an nvidia chip's feature
- * @param ptr_chipfeature: Pointer to chip feature to refresh
- * @param ptr_unused: currently unused
+ * @param feature: Chip feature to refresh
  */
-void refresh_nvidia (gpointer ptr_chipfeature, gpointer ptr_unused);
+void refresh_nvidia (const Ptr<t_chipfeature> &feature);
 
 /**
  * Read the temperature value from GPU
